@@ -8,12 +8,7 @@ __doc__ = \
 *the static method ``.params_to_pose(paramsfile:str, name:str)``, which returns a pose.
 
 """
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "10 July 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.0"
-__citation__ = "None."
+from .version import *
 
 ########################################################################################################################
 
@@ -30,7 +25,7 @@ class _PoserMixin:
         :param outfile: optionally save file.
         :return: pose
         """
-        self.log.debug(f'Testing params {outfile}')
+        self.log.debug(f'Testing params {"(writing out as "+outfile+")" if outfile is not None else "(no saving)"}')
         pose = self.to_pose(relax=True)
         assert pose.total_residue() == 1, 'Residue failed.'
         if outfile:
@@ -42,21 +37,35 @@ class _PoserMixin:
         # add paramsblock
         rts = self.add_residuetype(pose)
         # add new residue
-        lig = pyrosetta.rosetta.core.conformation.ResidueFactory.create_residue(rts.name_map('LIG'))
+        lig = pyrosetta.rosetta.core.conformation.ResidueFactory.create_residue(rts.name_map(self.NAME))
         pose.append_residue_by_jump(lig, 1)
         if relax:
-            cycles = 15
-            scorefxn = pyrosetta.get_fa_scorefxn()
-            relax = pyrosetta.rosetta.protocols.relax.FastRelax(scorefxn, cycles)
-            relax.apply(pose)
+            self._relax(pose)
         return pose
 
+    def to_polymeric_pose(self, relax=False, sequence:Optional[str]=None):
+        if sequence is None:
+            sequence = f'AX[{self.name}]A'
+        pose = pyrosetta.Pose()
+        rts = self.add_residuetype(pose)
+        pyrosetta.rosetta.core.pose.make_pose_from_sequence(pose, sequence, rts)
+        if relax:
+            self._relax(pose)
+        return pose
+
+    def _relax(self, pose, scorefxn: Optional[pyrosetta.ScoreFunction]=None, cycles: Optional[int] = 15):
+        if scorefxn is None:
+            scorefxn = pyrosetta.get_fa_scorefxn()
+        relax = pyrosetta.rosetta.protocols.relax.FastRelax(scorefxn, cycles)
+        relax.apply(pose)
+
     def add_residuetype(self, pose: pyrosetta.Pose) -> pyrosetta.rosetta.core.chemical.ResidueTypeSet:
         rts = pose.conformation().modifiable_residue_type_set_for_conf(pyrosetta.rosetta.core.chemical.FULL_ATOM_t)
         buffer = pyrosetta.rosetta.std.stringbuf(self.dumps())
         stream = pyrosetta.rosetta.std.istream(buffer)
-        new = pyrosetta.rosetta.core.chemical.read_topology_file(stream, self.NAME,
-                                                                 rts)  # no idea what the second argument does
+        new = pyrosetta.rosetta.core.chemical.read_topology_file(stream,
+                                                                 self.NAME,
+                                                                 rts)
         rts.add_base_residue_type(new)
         return rts
 
@@ -74,6 +83,6 @@ class _PoserMixin:
         params_paths = pyrosetta.rosetta.utility.vector1_string()
         params_paths.extend([paramsfile])
         resiset = pyrosetta.generate_nonstandard_residue_set(pose, params_paths)
-        lig = pyrosetta.rosetta.core.conformation.ResidueFactory.create_residue( rts.name_map( name ) )
+        lig = pyrosetta.rosetta.core.conformation.ResidueFactory.create_residue( resiset.name_map( name ) )
         pose.append_residue_by_jump(lig, 1)
         return pose
