@@ -4,13 +4,7 @@ __doc__ = \
 The main class here is `Entries``, which is a fancy list. It gets called for each uppercase attribute 
 in the initialisation of ``Params`` (which happens in ``_ParamsInitMixin`` __e.g.__ ``Entries.from_name('IO_STRING')``).
     """
-
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "5 November 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.3"
-__citation__ = "None."
+from .version import *
 
 ########################################################################################################################
 
@@ -227,6 +221,8 @@ class IO_STRINGEntry:
     name1: str = 'Z'
 
     def __post_init__(self):
+        if len(self.name3) == 2:
+            self.name3 += ' '
         assert len(self.name3) == 3, f'{self.name3} is not 3 char long'
         assert len(self.name1) == 1, f'{self.name1} is not 1 char long'
 
@@ -477,6 +473,31 @@ class CUT_BONDEntry:
 Entries.choices['CUT_BOND'] = (CUT_BONDEntry, Singletony.multiton)
 
 
+#########################################################################################################
+
+@dataclass
+class CHARGEEntry:
+    """
+    No idea if anything respects this.
+    """
+    atom: str
+    charge: int
+
+    def __str__(self) -> str:
+        return f'CHARGE {self.atom} FORMAL {self.charge}'
+
+    @classmethod
+    def from_str(cls, text: str):
+        rex = re.match('(\w+) FORMAL ([-\d])', text)
+        if rex is None:
+            raise ValueError(f'CHARGE entry "{text}" is not formatted correctly')
+        data = dict(zip(('atom', 'charge'), rex.groups()))
+        return cls(**data)
+
+
+Entries.choices['CHARGE'] = (CHARGEEntry, Singletony.multiton)
+
+
 #########################################################################################################
 
 class PDB_ROTAMERSEntry(GenericEntry):
