@@ -14,12 +14,7 @@ __doc__ = \
     * **convert** converts the mol into params entries
     """
 
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "10 July 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.0"
-__citation__ = "None."
+from ..version import *
 
 ########################################################################################################################
 
