@@ -5,12 +5,7 @@ __doc__ = \
     Various entry points.
     """
 
-__author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
-__email__ = "matteo.ferla@gmail.com"
-__date__ = "5 November 2020 A.D."
-__license__ = "MIT"
-__version__ = "1.1.3"
-__citation__ = "None."
+from ..version import *
 
 ########################################################################################################################
 
