@@ -5,13 +5,13 @@ pyrosetta.init(extra_options='-mute all')  # required for test
 from rdkit_to_params import Params
 from rdkit import Chem
 
-class MyTestCase(unittest.TestCase):
+class ParamTestCases(unittest.TestCase):
     def test_load(self):
-        p = Params.load('example/official_PHE.params')
+        p = Params.load('../example/official_PHE.params')
         self.assertEqual(p.NAME, 'PHE')
 
     def test_round(self):
-        p = Params.load('example/official_PHE.params')
+        p = Params.load('../example/official_PHE.params')
         p.IO_STRING[0].name3 = 'PHX'
         p.IO_STRING[0].name1 = 'Z'
         p.AA = 'UNK'  # If it's not one of the twenty (plus extras), UNK!
@@ -27,7 +27,7 @@ class MyTestCase(unittest.TestCase):
     def test_smiles(self):
         p = Params.from_smiles('*C(=O)C(Cc1ccccc1)[NH]*',  # recognised as amino acid.
                                name='PHX',  # optional.
-                               atomnames={3: 'CZ'}  # optional, rando atom name
+                               atomnames={4: 'CZ'}  # optional, rando atom name for CB
                                )
         self.assertTrue(p.is_aminoacid())
 
@@ -38,7 +38,5 @@ class MyTestCase(unittest.TestCase):
         self.assertEqual(p.ATOM[0].name, ' CZ ')
         p.test()
 
-
-
 if __name__ == '__main__':
     unittest.main()
